# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.job_spec_input import JobSpecInput

class TestJobSpecInput(unittest.TestCase):
    """JobSpecInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobSpecInput:
        """Test JobSpecInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobSpecInput`
        """
        model = JobSpecInput()
        if include_optional:
            return JobSpecInput(
                executable = '/usr/bin/python',
                container = { },
                arguments = [-n, 100],
                directory = '/home/user/work',
                name = 'my-job',
                inherit_environment = True,
                environment = {OMP_NUM_THREADS=4},
                stdin_path = '/home/user/input.txt',
                stdout_path = '/home/user/output.txt',
                stderr_path = '/home/user/error.txt',
                resources = {
                    'key' : null
                    },
                attributes = { },
                pre_launch = 'module load cuda',
                post_launch = 'echo done',
                launcher = 'srun'
            )
        else:
            return JobSpecInput(
        )
        """

    def testJobSpecInput(self):
        """Test JobSpecInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
