# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.incident import Incident

class TestIncident(unittest.TestCase):
    """Incident unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Incident:
        """Test Incident
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Incident`
        """
        model = Incident()
        if include_optional:
            return Incident(
                id = 'urn:iri:object:1234',
                name = '',
                description = '',
                last_modified = '2026-02-21T12:00:00Z',
                status = 'up',
                start = '2026-02-21T12:00:00Z',
                end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                type = 'planned',
                resolution = 'unresolved',
                self_uri = '',
                event_uris = [
                    ''
                    ],
                resource_uris = [
                    ''
                    ]
            )
        else:
            return Incident(
                id = 'urn:iri:object:1234',
                last_modified = '2026-02-21T12:00:00Z',
                status = 'up',
                start = '2026-02-21T12:00:00Z',
                type = 'planned',
                resolution = 'unresolved',
                self_uri = '',
                event_uris = [
                    ''
                    ],
                resource_uris = [
                    ''
                    ],
        )
        """

    def testIncident(self):
        """Test Incident"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
