# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.api.compute_api import ComputeApi


class TestComputeApi(unittest.TestCase):
    """ComputeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ComputeApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_job(self) -> None:
        """Test case for cancel_job

        Cancel Job
        """
        pass

    def test_get_job(self) -> None:
        """Test case for get_job

        Get Job Status
        """
        pass

    def test_get_jobs(self) -> None:
        """Test case for get_jobs

        Get Job Statuses
        """
        pass

    def test_launch_job(self) -> None:
        """Test case for launch_job

        Submit Job
        """
        pass

    def test_update_job(self) -> None:
        """Test case for update_job

        Update Job
        """
        pass


if __name__ == '__main__':
    unittest.main()
