# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.api.account_api import AccountApi


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountApi()

    def tearDown(self) -> None:
        pass

    def test_get_capabilities(self) -> None:
        """Test case for get_capabilities

        Get the list of capabilities
        """
        pass

    def test_get_capability(self) -> None:
        """Test case for get_capability

        Get a single capability
        """
        pass

    def test_get_project(self) -> None:
        """Test case for get_project

        Get a single project
        """
        pass

    def test_get_project_allocation_by_project(self) -> None:
        """Test case for get_project_allocation_by_project

        Get a single project allocation
        """
        pass

    def test_get_project_allocations_by_project(self) -> None:
        """Test case for get_project_allocations_by_project

        Get the allocations of the current user's projects
        """
        pass

    def test_get_projects(self) -> None:
        """Test case for get_projects

        Get the projects of the current user
        """
        pass

    def test_get_user_allocation_by_project_allocation(self) -> None:
        """Test case for get_user_allocation_by_project_allocation

        Get a user allocation of the current user's projects
        """
        pass

    def test_get_user_allocations_by_project_allocation(self) -> None:
        """Test case for get_user_allocations_by_project_allocation

        Get the user allocations of the current user's projects
        """
        pass


if __name__ == '__main__':
    unittest.main()
