# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.api.filesystem_api import FilesystemApi


class TestFilesystemApi(unittest.TestCase):
    """FilesystemApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesystemApi()

    def tearDown(self) -> None:
        pass

    def test_checksum(self) -> None:
        """Test case for checksum

        Get Checksum
        """
        pass

    def test_chmod(self) -> None:
        """Test case for chmod

        Put Chmod
        """
        pass

    def test_chown(self) -> None:
        """Test case for chown

        Put Chown
        """
        pass

    def test_compress(self) -> None:
        """Test case for compress

        Post Compress
        """
        pass

    def test_cp(self) -> None:
        """Test case for cp

        Post Cp
        """
        pass

    def test_download(self) -> None:
        """Test case for download

        Get Download
        """
        pass

    def test_extract(self) -> None:
        """Test case for extract

        Post Extract
        """
        pass

    def test_file(self) -> None:
        """Test case for file

        Get File
        """
        pass

    def test_head(self) -> None:
        """Test case for head

        Get Head
        """
        pass

    def test_ls(self) -> None:
        """Test case for ls

        Get Ls Async
        """
        pass

    def test_mkdir(self) -> None:
        """Test case for mkdir

        Post Mkdir
        """
        pass

    def test_mv(self) -> None:
        """Test case for mv

        Move Mv
        """
        pass

    def test_rm(self) -> None:
        """Test case for rm

        Delete Rm
        """
        pass

    def test_stat(self) -> None:
        """Test case for stat

        Get Stat
        """
        pass

    def test_symlink(self) -> None:
        """Test case for symlink

        Post Symlink
        """
        pass

    def test_tail(self) -> None:
        """Test case for tail

        Get Tail
        """
        pass

    def test_upload(self) -> None:
        """Test case for upload

        Post Upload
        """
        pass

    def test_view(self) -> None:
        """Test case for view

        Get View
        """
        pass


if __name__ == '__main__':
    unittest.main()
