# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.project import Project

class TestProject(unittest.TestCase):
    """Project unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Project:
        """Test Project
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Project`
        """
        model = Project()
        if include_optional:
            return Project(
                id = 'proj-abc123',
                name = 'Climate Simulation',
                description = 'Research project studying atmospheric dynamics.',
                user_ids = [user-123, user-456],
                last_modified = '2026-02-21T14:30:00Z',
                self_uri = ''
            )
        else:
            return Project(
                id = 'proj-abc123',
                name = 'Climate Simulation',
                description = 'Research project studying atmospheric dynamics.',
                user_ids = [user-123, user-456],
                last_modified = '2026-02-21T14:30:00Z',
                self_uri = '',
        )
        """

    def testProject(self):
        """Test Project"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
