# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.put_file_chown_request import PutFileChownRequest

class TestPutFileChownRequest(unittest.TestCase):
    """PutFileChownRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PutFileChownRequest:
        """Test PutFileChownRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PutFileChownRequest`
        """
        model = PutFileChownRequest()
        if include_optional:
            return PutFileChownRequest(
                path = '',
                owner = '',
                group = ''
            )
        else:
            return PutFileChownRequest(
        )
        """

    def testPutFileChownRequest(self):
        """Test PutFileChownRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
