# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.compression_type import CompressionType

class TestCompressionType(unittest.TestCase):
    """CompressionType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCompressionType(self):
        """Test CompressionType"""
        # inst = CompressionType()

if __name__ == '__main__':
    unittest.main()
